==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/ApplicationLayoutRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.HashMap;
import java.util.Map;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ApplicationLayoutRuleCondition
 */
@JsonPropertyOrder({ ApplicationLayoutRuleCondition.JSON_PROPERTY_SCHEMA,
        ApplicationLayoutRuleCondition.JSON_PROPERTY_SCOPE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ApplicationLayoutRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SCHEMA = "schema";
    private Map<String, Object> schema = null;

    public static final String JSON_PROPERTY_SCOPE = "scope";
    private String scope;

    public ApplicationLayoutRuleCondition() {
    }

    public ApplicationLayoutRuleCondition schema(Map<String, Object> schema) {

        this.schema = schema;
        return this;
    }

    public ApplicationLayoutRuleCondition putschemaItem(String key, Object schemaItem) {
        if (this.schema == null) {
            this.schema = new HashMap<>();
        }
        this.schema.put(key, schemaItem);
        return this;
    }

    /**
     * Get schema
     *
     * @return schema
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SCHEMA)
    @JsonInclude(content = JsonInclude.Include.ALWAYS, value = JsonInclude.Include.USE_DEFAULTS)

    public Map<String, Object> getSchema() {
        return schema;
    }

    @JsonProperty(JSON_PROPERTY_SCHEMA)
    @JsonInclude(content = JsonInclude.Include.ALWAYS, value = JsonInclude.Include.USE_DEFAULTS)
    public void setSchema(Map<String, Object> schema) {
        this.schema = schema;
    }

    public ApplicationLayoutRuleCondition scope(String scope) {

        this.scope = scope;
        return this;
    }

    /**
     * Get scope
     *
     * @return scope
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SCOPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getScope() {
        return scope;
    }

    @JsonProperty(JSON_PROPERTY_SCOPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setScope(String scope) {
        this.scope = scope;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ApplicationLayoutRuleCondition applicationLayoutRuleCondition = (ApplicationLayoutRuleCondition) o;
        return Objects.equals(this.schema, applicationLayoutRuleCondition.schema)
                && Objects.equals(this.scope, applicationLayoutRuleCondition.scope);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(schema, scope);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ApplicationLayoutRuleCondition {\n");
        sb.append("    schema: ").append(toIndentedString(schema)).append("\n");
        sb.append("    scope: ").append(toIndentedString(scope)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/ApplicationLayoutRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.HashMap;
import java.util.Map;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ApplicationLayoutRuleCondition
 */
@JsonPropertyOrder({ ApplicationLayoutRuleCondition.JSON_PROPERTY_SCHEMA,
        ApplicationLayoutRuleCondition.JSON_PROPERTY_SCOPE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class ApplicationLayoutRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SCHEMA = "schema";
    private Map<String, Object> schema = null;

    public static final String JSON_PROPERTY_SCOPE = "scope";
    private String scope;

    public ApplicationLayoutRuleCondition() {
    }

    public ApplicationLayoutRuleCondition schema(Map<String, Object> schema) {

        this.schema = schema;
        return this;
    }

    public ApplicationLayoutRuleCondition putschemaItem(String key, Object schemaItem) {
        if (this.schema == null) {
            this.schema = new HashMap<>();
        }
        this.schema.put(key, schemaItem);
        return this;
    }

    /**
     * Get schema
     *
     * @return schema
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SCHEMA)
    @JsonInclude(content = JsonInclude.Include.ALWAYS, value = JsonInclude.Include.USE_DEFAULTS)

    public Map<String, Object> getSchema() {
        return schema;
    }

    @JsonProperty(JSON_PROPERTY_SCHEMA)
    @JsonInclude(content = JsonInclude.Include.ALWAYS, value = JsonInclude.Include.USE_DEFAULTS)
    public void setSchema(Map<String, Object> schema) {
        this.schema = schema;
    }

    public ApplicationLayoutRuleCondition scope(String scope) {

        this.scope = scope;
        return this;
    }

    /**
     * Get scope
     *
     * @return scope
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SCOPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getScope() {
        return scope;
    }

    @JsonProperty(JSON_PROPERTY_SCOPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setScope(String scope) {
        this.scope = scope;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ApplicationLayoutRuleCondition applicationLayoutRuleCondition = (ApplicationLayoutRuleCondition) o;
        return Objects.equals(this.schema, applicationLayoutRuleCondition.schema)
                && Objects.equals(this.scope, applicationLayoutRuleCondition.scope);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(schema, scope);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ApplicationLayoutRuleCondition {\n");
        sb.append("    schema: ").append(toIndentedString(schema)).append("\n");
        sb.append("    scope: ").append(toIndentedString(scope)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
